@@ -16,14 +16,14 @@ use Cwd qw'abs_path cwd';
 
 use Ruby::VersionManager::Version;
 
-has rootdir => ( is => 'rw' );
-has ruby_version => ( is => 'rw' );
-has major_version => ( is => 'rw' );
+has rootdir          => ( is => 'rw' );
+has ruby_version     => ( is => 'rw' );
+has major_version    => ( is => 'rw' );
 has rubygems_version => ( is => 'rw' );
 has available_rubies => ( is => 'rw' );
-has agent_string => ( is => 'rw' );
-has archive_type => ( is => 'rw' );
-has gemset => ( is => 'rw' );
+has agent_string     => ( is => 'rw' );
+has archive_type     => ( is => 'rw' );
+has gemset           => ( is => 'rw' );
 has installed_rubies => ( is => 'rw' );
 
 sub BUILD {
@@ -31,11 +31,11 @@ sub BUILD {
 
     my $v = Ruby::VersionManager::Version->new;
 
-    $self->agent_string('Ruby::VersionManager/' . $v->get);
+    $self->agent_string( 'Ruby::VersionManager/' . $v->get );
     $self->archive_type('.tar.bz2') unless $self->archive_type;
-    $self->rootdir(abs_path($self->rootdir)) if $self->rootdir;
+    $self->rootdir( abs_path( $self->rootdir ) ) if $self->rootdir;
     $self->_make_base or die;
-    $self->_check_db or die;
+    $self->_check_db  or die;
     $self->_check_installed;
     $self->gemset('default') unless $self->gemset;
 
@@ -44,9 +44,9 @@ sub BUILD {
 sub _make_base {
     my ($self) = @_;
 
-    $self->rootdir($ENV{'HOME'} . '/.ruby_vmanager') unless $self->rootdir;
+    $self->rootdir( $ENV{'HOME'} . '/.ruby_vmanager' ) unless $self->rootdir;
 
-    if (not -d $self->rootdir){
+    if ( not -d $self->rootdir ) {
         say "root directory for installation not found.\nbootstraping to " . $self->rootdir;
         mkdir $self->rootdir;
         mkdir $self->rootdir . '/bin';
@@ -64,24 +64,24 @@ sub _check_db {
     my ($self) = @_;
 
     $self->updatedb unless -f $self->rootdir . '/var/db.yml';
-    $self->available_rubies(YAML::LoadFile($self->rootdir . '/var/db.yml'));
+    $self->available_rubies( YAML::LoadFile( $self->rootdir . '/var/db.yml' ) );
 
 }
 
 sub _check_installed {
     my ($self) = @_;
 
-    my $rubies = {};
+    my $rubies         = {};
     my $checked_rubies = {};
 
-    if (-f $self->rootdir . '/var/installed.yml'){
-        $rubies = YAML::LoadFile($self->rootdir . '/var/installed.yml');
+    if ( -f $self->rootdir . '/var/installed.yml' ) {
+        $rubies = YAML::LoadFile( $self->rootdir . '/var/installed.yml' );
     }
 
-    for my $major (keys %$rubies){
-        for my $ruby (@{$rubies->{$major}}){
-            if (-x $self->rootdir . '/rubies/' . $major . '/' . $ruby . '/bin/ruby'){
-                push @{$checked_rubies->{$major}}, $ruby;
+    for my $major ( keys %$rubies ) {
+        for my $ruby ( @{ $rubies->{$major} } ) {
+            if ( -x $self->rootdir . '/rubies/' . $major . '/' . $ruby . '/bin/ruby' ) {
+                push @{ $checked_rubies->{$major} }, $ruby;
             }
         }
     }
@@ -93,35 +93,32 @@ sub _check_installed {
 sub updatedb {
     my ($self) = @_;
 
-    my @versions = (
-        1.8,
-        1.9,
-    );
+    my @versions = ( 1.8, 1.9, );
 
     my $rubies = {};
 
-    for my $version (@versions){
+    for my $version (@versions) {
         my $ruby_ftp = 'ftp://ftp.ruby-lang.org/pub/ruby/' . $version;
-        my $req = HTTP::Request->new(GET => $ruby_ftp);
+        my $req = HTTP::Request->new( GET => $ruby_ftp );
 
         my $ua = LWP::UserAgent->new;
-        $ua->agent($self->agent_string);
+        $ua->agent( $self->agent_string );
 
         my $res = $ua->request($req);
 
-        if ($res->is_success){
+        if ( $res->is_success ) {
             $rubies->{$version} = [];
-            for (grep { $_ ~~ /ruby-.*\.tar\.bz2/ } split '\n', $res->content){
+            for ( grep { $_ ~~ /ruby-.*\.tar\.bz2/ } split '\n', $res->content ) {
                 my $at = $self->archive_type;
-                (my $ruby = $_) =~ s/(.*)$at/$1/;
-                push @{$rubies->{$version}}, (split ' ', $ruby)[-1];
+                ( my $ruby = $_ ) =~ s/(.*)$at/$1/;
+                push @{ $rubies->{$version} }, ( split ' ', $ruby )[-1];
             }
         }
     }
 
     die "Did not get any data from ftp.ruby-lang.org" unless %$rubies;
 
-    YAML::DumpFile($self->rootdir . '/var/db.yml', $rubies);
+    YAML::DumpFile( $self->rootdir . '/var/db.yml', $rubies );
 
     $self->_check_db;
 
@@ -132,9 +129,9 @@ sub uninstall {
 
     return 0 unless $self->ruby_version;
 
-    for my $major (keys %{$self->installed_rubies}){
-        for my $ruby (@{$self->installed_rubies->{$major}}){
-            if ($ruby eq $self->ruby_version){
+    for my $major ( keys %{ $self->installed_rubies } ) {
+        for my $ruby ( @{ $self->installed_rubies->{$major} } ) {
+            if ( $ruby eq $self->ruby_version ) {
                 $self->major_version($major);
                 $self->_remove_ruby;
                 $self->_remove_source;
@@ -165,70 +162,61 @@ sub list {
     my ($self) = @_;
 
     $self->_check_db or die;
-    my %rubies = %{$self->available_rubies};
-    my %installed = %{$self->installed_rubies};
+    my %rubies    = %{ $self->available_rubies };
+    my %installed = %{ $self->installed_rubies };
 
     say "Available ruby versions";
-    for (keys %rubies){
+    for ( keys %rubies ) {
         say "\tVersion $_:";
         my @rubies = $self->_sort_rubies( $rubies{$_} );
-        for (@rubies){
+        for (@rubies) {
             my $at = $self->archive_type;
-            (my $ruby = $_) =~ s/(.*)$at/$1/;
+            ( my $ruby = $_ ) =~ s/(.*)$at/$1/;
             say "\t\t$ruby";
         }
     }
 
     say "Installed ruby versions";
-    for (keys %installed){
+    for ( keys %installed ) {
         say "\tVersion: $_";
-        for (@{$installed{$_}}){
+        for ( @{ $installed{$_} } ) {
             say "\t\t$_";
         }
     }
 }
 
 sub _sort_rubies {
-    my ($self, $rubies) = @_;
+    my ( $self, $rubies ) = @_;
 
     my @sorted = ();
     my $major_versions;
 
-    for (@$rubies){
-        my (undef, $major, $patchlevel) = split '-', $_;
+    for (@$rubies) {
+        my ( undef, $major, $patchlevel ) = split '-', $_;
         $major_versions->{$major} = [] unless $major_versions->{$major};
-        push @{$major_versions->{$major}}, $patchlevel;
+        push @{ $major_versions->{$major} }, $patchlevel;
     }
 
-    for my $version (sort { $a cmp $b } keys %{$major_versions}){
-        my @patchlevels = grep {
-                                defined $_
-                                &&
-                                $_ =~ /p\d{1,3}/
-                          } @{$major_versions->{$version}};
-        my @pre = grep {
-                        defined $_
-                        &&
-                        $_ =~ /preview\d{0,1}|rc\d{0,1}/
-                  } @{$major_versions->{$version}};
-        my @old = grep {
-                        defined $_
-                        &&
-                        $_ =~ /^\d/
-                  } @{$major_versions->{$version}};
+    for my $version ( sort { $a cmp $b } keys %{$major_versions} ) {
+        my @patchlevels
+            = grep { defined $_ && $_ =~ /p\d{1,3}/ } @{ $major_versions->{$version} };
+        my @pre
+            = grep { defined $_ && $_ =~ /preview\d{0,1}|rc\d{0,1}/ } @{ $major_versions->{$version} };
+        my @old
+            = grep { defined $_ && $_ =~ /^\d/ } @{ $major_versions->{$version} };
 
         my @numeric_levels;
-        for my $level (@patchlevels){
-            (my $num = $level) =~ s/p(\d+)/$1/;
+        for my $level (@patchlevels) {
+            ( my $num = $level ) =~ s/p(\d+)/$1/;
             push @numeric_levels, $num;
         }
 
         @patchlevels = ();
-        for (sort { $a <=> $b } @numeric_levels){
+        for ( sort { $a <=> $b } @numeric_levels ) {
             push @patchlevels, 'p' . $_;
         }
 
-        for ( (sort { $a cmp $b } @old), @patchlevels, (sort { $a cmp $b } @pre) ){
+        for ( ( sort { $a cmp $b } @old ), @patchlevels, ( sort { $a cmp $b } @pre ) ) {
             push @sorted, "ruby-$version-$_";
         }
 
@@ -240,22 +228,23 @@ sub _sort_rubies {
 sub _guess_version {
     my ($self) = @_;
 
-    my @rubies = ();
+    my @rubies      = ();
     my $req_version = $self->ruby_version;
+
     # 1.8 or 1.9?
-    for my $major_version (keys %{$self->available_rubies}){
-        if ($req_version =~ /$major_version/){
-            for my $ruby (@{$self->available_rubies->{$major_version}}){
-                if ($ruby =~ /$req_version/){
+    for my $major_version ( keys %{ $self->available_rubies } ) {
+        if ( $req_version =~ /$major_version/ ) {
+            for my $ruby ( @{ $self->available_rubies->{$major_version} } ) {
+                if ( $ruby =~ /$req_version/ ) {
 
                     my $at = $self->archive_type;
-                    ($ruby = $ruby) =~ s/(.*)$at/$1/;
+                    ( $ruby = $ruby ) =~ s/(.*)$at/$1/;
 
-                    if ($ruby eq $req_version){
+                    if ( $ruby eq $req_version ) {
                         push @rubies, $ruby;
                         last;
                     }
-                    elsif ($ruby =~ /preview|rc\d?+/){
+                    elsif ( $ruby =~ /preview|rc\d?+/ ) {
                         next;
                     }
 
@@ -265,9 +254,9 @@ sub _guess_version {
         }
     }
 
-    my $guess = ($self->_sort_rubies([@rubies]))[-1];
+    my $guess = ( $self->_sort_rubies( [@rubies] ) )[-1];
 
-    if (not $guess){
+    if ( not $guess ) {
         say "No matching version found. Valid versions:";
         $self->list;
 
@@ -280,15 +269,15 @@ sub _guess_version {
 sub install {
     my ($self) = @_;
 
-    $self->ruby_version($self->_guess_version);
-    (my $major_version = $self->ruby_version) =~ s/ruby-(\d\.\d).*/$1/;
+    $self->ruby_version( $self->_guess_version );
+    ( my $major_version = $self->ruby_version ) =~ s/ruby-(\d\.\d).*/$1/;
     $self->major_version($major_version);
 
-    my $ruby = $self->ruby_version;
+    my $ruby      = $self->ruby_version;
     my $installed = 0;
-    $installed = 1 if join ' ', @{$self->installed_rubies->{$major_version}} ~~ /$ruby/;
+    $installed = 1 if join ' ', @{ $self->installed_rubies->{$major_version} } ~~ /$ruby/;
 
-    if (not $installed){
+    if ( not $installed ) {
         $self->_fetch_ruby;
         $self->_unpack_ruby;
         $self->_make_install;
@@ -296,29 +285,25 @@ sub install {
 
     $self->_setup_environment;
 
-    if (not $installed){
+    if ( not $installed ) {
         $self->_install_rubygems;
-        push @{$self->installed_rubies->{$major_version}}, $ruby unless $installed;
+        push @{ $self->installed_rubies->{$major_version} }, $ruby unless $installed;
         $self->_update_installed;
     }
 
-
 }
 
 sub _update_installed {
     my ($self) = @_;
 
-    YAML::DumpFile($self->rootdir . '/var/installed.yml', $self->installed_rubies);
+    YAML::DumpFile( $self->rootdir . '/var/installed.yml', $self->installed_rubies );
 
 }
 
 sub _unpack_ruby {
     my ($self) = @_;
 
-    system 'tar xf ' . $self->rootdir . '/source/'
-            . $self->ruby_version . $self->archive_type
-            . ' -C  '
-            . $self->rootdir . '/source/';
+    system 'tar xf ' . $self->rootdir . '/source/' . $self->ruby_version . $self->archive_type . ' -C  ' . $self->rootdir . '/source/';
 
     return 1;
 }
@@ -343,62 +328,17 @@ sub _setup_environment {
     my ($self) = @_;
 
     $ENV{RUBY_VERSION} = $self->ruby_version;
-    $ENV{GEM_PATH} = abs_path($self->rootdir) . '/gemsets/'
-        . $self->major_version
-        . '/'
-        . $self->ruby_version
-        . '/'
-        . $self->gemset;
-    $ENV{GEM_HOME} = abs_path($self->rootdir) . '/gemsets/'
-        . $self->major_version
-        . '/'
-        . $self->ruby_version
-        . '/'
-        . $self->gemset;
-    $ENV{MY_RUBY_HOME} = abs_path($self->rootdir)
-        . '/rubies/'
-        . $self->major_version
-        . '/'
-        . $self->ruby_version;
-    $ENV{PATH} = abs_path($self->rootdir)
-        . '/rubies/'
-        . $self->major_version
-        . '/'
-        . $self->ruby_version
-        . '/bin'
-        . ':'
-        . abs_path($self->rootdir)
-        . '/gemsets/'
-        . $self->major_version
-        . '/'
-        . $self->ruby_version
-        . '/'
-        . $self->gemset
-        . '/bin'
-        . ':'
-        . $ENV{PATH};
+    $ENV{GEM_PATH}     = abs_path( $self->rootdir ) . '/gemsets/' . $self->major_version . '/' . $self->ruby_version . '/' . $self->gemset;
+    $ENV{GEM_HOME}     = abs_path( $self->rootdir ) . '/gemsets/' . $self->major_version . '/' . $self->ruby_version . '/' . $self->gemset;
+    $ENV{MY_RUBY_HOME} = abs_path( $self->rootdir ) . '/rubies/' . $self->major_version . '/' . $self->ruby_version;
+    $ENV{PATH}         = abs_path( $self->rootdir ) . '/rubies/' . $self->major_version . '/' . $self->ruby_version . '/bin' . ':' . abs_path( $self->rootdir ) . '/gemsets/' . $self->major_version . '/' . $self->ruby_version . '/' . $self->gemset . '/bin' . ':' . $ENV{PATH};
 
     open my $rcfile, '>', $self->rootdir . '/var/ruby_vmanager.rc';
     say $rcfile 'export RUBY_VERSION=' . $self->ruby_version;
     say $rcfile 'export GEM_PATH=' . $ENV{GEM_PATH};
     say $rcfile 'export GEM_HOME=' . $ENV{GEM_HOME};
     say $rcfile 'export MY_RUBY_HOME=' . $ENV{MY_RUBY_HOME};
-    say $rcfile 'export PATH=' . abs_path($self->rootdir)
-        . '/rubies/'
-        . $self->major_version
-        . '/'
-        . $self->ruby_version
-        . '/bin'
-        . ':'
-        . abs_path($self->rootdir)
-        . '/gemsets/'
-        . $self->major_version
-        . '/'
-        . $self->ruby_version
-        . '/'
-        . $self->gemset
-        . '/bin'
-        . ':$PATH';
+    say $rcfile 'export PATH=' . abs_path( $self->rootdir ) . '/rubies/' . $self->major_version . '/' . $self->ruby_version . '/bin' . ':' . abs_path( $self->rootdir ) . '/gemsets/' . $self->major_version . '/' . $self->ruby_version . '/' . $self->gemset . '/bin' . ':$PATH';
 
     close $rcfile;
 
@@ -408,19 +348,15 @@ sub _setup_environment {
 sub _fetch_ruby {
     my ($self) = @_;
 
-    my $url = 'ftp://ftp.ruby-lang.org/pub/ruby/'
-              . $self->major_version
-              . '/'
-              . $self->ruby_version
-              . $self->archive_type;
+    my $url = 'ftp://ftp.ruby-lang.org/pub/ruby/' . $self->major_version . '/' . $self->ruby_version . $self->archive_type;
 
     my $file = $self->rootdir . '/source/' . $self->ruby_version . $self->archive_type;
 
-    if ( -f $file ){
-        return 1
+    if ( -f $file ) {
+        return 1;
     }
 
-    my $result = LWP::Simple::getstore($url, $file);
+    my $result = LWP::Simple::getstore( $url, $file );
 
     die if $result != 200;
 
@@ -431,16 +367,15 @@ sub _fetch_ruby {
 sub _install_rubygems {
     my ($self) = @_;
 
-    unless (-f $ENV{MY_RUBY_HOME} . '/bin/gem'){
-        my $url = 'http://rubyforge.org/frs/download.php/70696/rubygems-1.3.7.tgz';
+    unless ( -f $ENV{MY_RUBY_HOME} . '/bin/gem' ) {
+        my $url  = 'http://rubyforge.org/frs/download.php/70696/rubygems-1.3.7.tgz';
         my $file = $self->rootdir . '/source/rubygems-1.3.7.tgz';
 
-        unless ( -f $file ){
-            my $result = LWP::Simple::getstore($url, $file);
+        unless ( -f $file ) {
+            my $result = LWP::Simple::getstore( $url, $file );
             die if $result != 200;
         }
 
-
         system 'tar xf ' . $file . ' -C ' . $self->rootdir . '/source/';
 
         my $cwd = cwd();
@@ -452,6 +387,8 @@ sub _install_rubygems {
     return 1;
 }
 
+1;
+
 __END__
 
 =head1 NAME
@@ -464,7 +401,7 @@ This is an unstable development release not ready for production!
 
 =head1 VERSION
 
-Version 0.003008
+Version 0.003009
 
 =head1 SYNOPSIS
 
@@ -491,7 +428,7 @@ Name your gemset. More sophisticated support for gemsets needs to be implemented
 =head2 agent_string
 
 The user agent used when downloading ruby.
-Defaults to Ruby::VersionManager/0.003008.
+Defaults to Ruby::VersionManager/0.003009.
 
 =head2 archive_type
 
